@@ -43,12 +43,10 @@
 #' @export
 bed_coverage <- function(x, y, ...) {
   
-  if ( ! is_sorted(x) )
-    x <- bed_sort(x)
-  if ( ! is_sorted(y) )
-    y <- bed_sort(y)
-  
+  x <- arrange(x, chrom, start)
   x <- group_by(x, chrom, add = TRUE)
+
+  y <- arrange(y, chrom, start)
   y <- group_by(y, chrom, add = TRUE)
   
   res <- coverage_impl(x, y)
