@@ -15,12 +15,12 @@ y <- tibble::tribble(
 
 test_that("simple overlap works", {
   res <- bed_intersect(x, y)
-  expect_equal(nrow(res), 4)   
+  expect_equal(nrow(res), 4)
 })
 
 test_that("invert param works", {
   res <- bed_intersect(x, y, invert = TRUE)
-  expect_equal(nrow(res), 1)   
+  expect_equal(nrow(res), 1)
 })
 
 test_that("multple a's", {
@@ -32,14 +32,14 @@ test_that("multple a's", {
     "chr1",    100,       200,
     "chr1",    100,       200
   )
-  
+
   y <- tibble::tribble(
     ~chrom,    ~start,    ~end,
     "chr1",    175,       200
   )
-  
+
   res <- bed_intersect(x, y)
-  expect_equal(nrow(res), 5)   
+  expect_equal(nrow(res), 5)
 })
 
 test_that("multple b's", {
@@ -47,7 +47,7 @@ test_that("multple b's", {
     ~chrom,    ~start,    ~end,
     "chr1",    100,       200
   )
-  
+
   y <- tibble::tribble(
     ~chrom,   ~start,    ~end,
     "chr1",    175,       200,
@@ -56,9 +56,9 @@ test_that("multple b's", {
     "chr1",    175,       200,
     "chr1",    175,       200
   )
-  
+
   res <- bed_intersect(x, y)
-  expect_equal(nrow(res), 5)   
+  expect_equal(nrow(res), 5)
 })
 
 test_that("no overlaps returns empty df", {
@@ -73,7 +73,7 @@ test_that("no overlaps returns empty df", {
   res <- bed_intersect(x, y)
   expect_is(res, "data.frame")
   expect_equal(nrow(res), 0)
-}) 
+})
 
 test_that("duplicate intervals are removed (#23)", {
   x <- tibble::tribble(
@@ -81,13 +81,13 @@ test_that("duplicate intervals are removed (#23)", {
     "chr1", 100,    500,
     "chr1", 175,    200
   )
-  
+
   y <- tibble::tribble(
     ~chrom, ~start, ~end,
     "chr1", 150,    400,
     "chr1", 151,    401
   )
-  
+
   res <- bed_intersect(x, y)
   expect_equal(nrow(res), 4)
 })
@@ -97,14 +97,14 @@ test_that("suffixes disambiguate x/y columns (#28)", {
     ~chrom, ~start, ~end, ~name, ~score, ~strand,
     "chr1", 1000,   1500, '.',   '.',     '-'
   )
-  
+
   y <- tibble::tribble(
     ~chrom, ~start, ~end, ~name, ~score, ~strand,
     "chr1", 1000,   1200, '.',   '.',     '-'
   )
-  
+
   res <- bed_intersect(x, y)
-  test_that("start.y" %in% colnames(res), TRUE)
+  expect_true("start.y" %in% colnames(res))
 })
 
 test_that("incorrect `suffix` args throw errors", {
@@ -112,13 +112,13 @@ test_that("incorrect `suffix` args throw errors", {
     ~chrom, ~start, ~end, ~name, ~score,
     "chr1", 1000,   1500, '.',   '.'
   )
-  
+
   y <- tibble::tribble(
     ~chrom, ~start, ~end, ~name, ~score,
     "chr1", 1000,   1200, '.',   '.'
   )
-  
-  expect_error(bed_intersect(x, y, suffix = 'TESTING')) 
+
+  expect_error(bed_intersect(x, y, suffix = 'TESTING'))
 })
 
 test_that("intersections from x bed_tbl with more chroms than y are captured", {
@@ -127,11 +127,11 @@ test_that("intersections from x bed_tbl with more chroms than y are captured", {
     "chr1",    100,       200,
     "chr3",    400,       500
   )
-  
+
   y <- tibble::tribble(
     ~chrom,   ~start,    ~end,
-    "chr3",    425,       475) 
-  
+    "chr3",    425,       475)
+
   res <- bed_intersect(x, y)
   expect_true("chr3" %in% res$chrom)
 })
@@ -141,12 +141,12 @@ test_that("intersections from y bed_tbl with more chroms are captured", {
     ~chrom,   ~start,    ~end,
     "chr3",    400,       500
   )
-  
+
   y <- tibble::tribble(
     ~chrom,   ~start,    ~end,
     "chr1",    100,       200,
-    "chr3",    425,       475) 
-  
+    "chr3",    425,       475)
+
   res <- bed_intersect(x, y)
   expect_true("chr3" %in% res$chrom)
 })
@@ -160,11 +160,11 @@ test_that("input x groups are used for comparing intervals issue #108",{
     'chr1', 125,    175,  'B',
     'chr1', 150,    200,  'B'
   )
-  x <- bed_sort(x)
+  x <- arrange(x, chrom, start)
   x <- group_by(x, group)
   res <- bed_intersect(x, x)
   expect_true(all(res$group.x == res$group.y))
-  
+
 })
 
 test_that("tbls grouped by strand are processed", {
@@ -172,16 +172,16 @@ test_that("tbls grouped by strand are processed", {
     ~chrom, ~start, ~end, ~name, ~score, ~strand,
     "chr1", 1000,   1500, '.',   '.',     '+'
   )
-  
+
   y <- tibble::tribble(
     ~chrom, ~start, ~end, ~name, ~score, ~strand,
     "chr1", 1000,   1200, '.',   '.',     '-'
   )
- 
+
   res <- bed_intersect(group_by(x, strand), group_by(y, strand))
   expect_equal(nrow(res), 0)
- 
-  # flip strands 
+
+  # flip strands
   res <- bed_intersect(group_by(x, strand), group_by(flip_strands(y), strand))
   expect_equal(nrow(res), 1)
 })
